use chrono::{DateTime, Utc};
use j_db::model::JdbModel;
use j_db::query::QueryBuilder;
use serde::{Deserialize, Serialize};

#[derive(Debug, Clone, Deserialize, Serialize)]
pub struct Album {
    pub album_name: String,
    pub images: Vec<u64>,
    pub aliases: Vec<String>,
    pub created_at: DateTime<Utc>,
    pub modified_at: DateTime<Utc>,
    pub owner: u64,

    id: Option<u64>,
}

impl Album {
    pub fn new(name: &str, aliases: Vec<String>, owner: u64) -> Album {
        Album {
            album_name: name.to_string(),
            images: vec![],
            aliases,
            created_at: Utc::now(),
            modified_at: Utc::now(),
            owner,
            id: None,
        }
    }
}

impl JdbModel for Album {
    fn id(&self) -> Option<u64> {
        self.id
    }

    fn set_id(&mut self, id: u64) {
        self.id = Some(id);
    }

    fn tree() -> String {
        "Album".to_string()
    }

    fn check_unique(&self, other: &Self) -> bool {
        other.album_name != self.album_name
    }
}


